@@ -66,6 +66,24 @@ def test_obj_groups():
     # assert g.np.ptp(mesh.metadata['face_groups']) > 0
 
 
+def test_obj_groups_split():
+    # a wavefront file with 14 groups and 2 objects defined
+    mesh = g.get_mesh("groups.obj", split_groups=True)
+    # make sure the right number of meshes are split
+    assert len(mesh.geometry) == 14
+
+    # keys of (split_object, split_groups) arguments
+    # values of how many meshes should be output for `groups.obj`
+    checks = {(True, True): 15, (True, False): 2, (False, True): 14, (False, False): 1}
+
+    for (split_objects, split_groups), truth in checks.items():
+        scene = g.get_scene(
+            "groups.obj", split_objects=split_objects, split_groups=split_groups
+        )
+        # make sure we produced the expected number of geometries
+        assert len(scene.geometry) == truth
+
+
 def test_obj_negative_indices():
     # a wavefront file with negative indices
     mesh = g.get_mesh("negative_indices.obj", merge_tex=True, merge_norm=True)
@@ -89,7 +107,7 @@ def test_obj_quad():
 
 def test_obj_multiobj():
     # test a wavefront file with multiple objects in the same file
-    scene = g.get_mesh("two_objects.obj", split_object=True, group_material=False)
+    scene = g.get_mesh("two_objects.obj", split_objects=True, group_material=False)
     assert len(scene.geometry) == 2
 
     for mesh in scene.geometry.values():
@@ -108,7 +126,7 @@ def test_obj_split_attributes():
     scene = g.get_mesh(
         "joined_tetrahedra.obj",
         process=False,
-        split_object=True,
+        split_objects=True,
         group_material=False,
     )
 
@@ -563,5 +581,4 @@ def test_obj_quad_uv():
 
 
 if __name__ == "__main__":
-    # test_material_name()
-    test_multi_nodupe()
+    test_obj_groups_split()
