@@ -138,9 +138,9 @@ def revolve(
     # this is a superset which will then be reduced
     quad = np.array([0, per, 1, 1, per, per + 1])
     # stack the faces for a single slice of the revolution
-    single = np.tile(quad, per).reshape((-1, 3))
+    single = np.tile(quad, per - 1).reshape((-1, 3))
     # `per` is basically the stride of the vertices
-    single += np.tile(np.arange(per), (2, 1)).T.reshape((-1, 1))
+    single += np.tile(np.arange(per - 1), (2, 1)).T.reshape((-1, 1))
     # remove any zero-area triangle
     # this covers many cases without having to think too much
     single = single[triangles.area(vertices[single]) > tol.merge]
@@ -159,9 +159,6 @@ def revolve(
     # offset stacked and wrap vertices
     faces = (stacked + offset) % len(vertices)
 
-    # if 'process' not in kwargs:
-    #    kwargs['process'] = False
-
     # Handle capping before applying any transformation
     if not closed and cap:
         # Use the triangulated linestring as the base cap faces (cap_0), assuming no new vertices
@@ -172,11 +169,10 @@ def revolve(
 
         if tol.strict:
             # make sure we didn't screw up triangulation
-            _, idx = np.unique(cap_0_vertices, return_index=True)
-            cap_0_uvtxs = cap_0_vertices[np.sort(idx)]
-            _, idx = np.unique(linestring, return_index=True)
-            line_uvtxs = linestring[np.sort(idx)]
-            assert np.allclose(cap_0_uvtxs, line_uvtxs)
+            unique = grouping.unique_rows(cap_0_vertices)[0]
+            assert set(unique) == set(range(len(linestring))), (
+                "Triangulation added vertices!"
+            )
 
         # Use the last set of vertices as the top cap contour (cap_angle)
         offset = len(vertices) - per
